/*
 * Autogenerated by the Meson build system.
 * Do not edit, your changes will be lost.
 */

#pragma once

#define FUSE_HOTFIX_VERSION 2

#define FUSE_MAJOR_VERSION 3

#define FUSE_MINOR_VERSION 18

#define FUSE_RC_VERSION 

#define LIBFUSE_BUILT_WITH_VERSIONED_SYMBOLS 1

